==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Ataria',
'articles' => 'Artikuluak',
'articles_auteur' => 'Egile honen artikuluak',
'articles_populaires' => 'artikulu arrakastatsuenak',
'articles_rubrique' => 'Eremu honetako artikuluak',
'aucun_article' => 'Ez dago artikulurik helbide honetan',
'aucun_auteur' => 'Ez dago egilerik helbide honetan',
'aucun_site' => 'ez dago gunerik helbide honetan',
'aucune_breve' => 'Ez dago laburrik helbide honetan',
'aucune_rubrique' => 'Ez dago gairik helbide honetan',
'autres' => 'Beste',
'autres_breves' => 'beste laburrak',
'autres_groupes_mots_clefs' => 'Beste gako-hitz multzoak',
'autres_sites' => 'Beste guneak',

// B
'bonjour' => 'Agur',
'breves' => 'Laburrak',

// C
'commenter_site' => 'Guneari buruz iruzkina egin',
'copie_document_impossible' => 'Dokumentua ezin da kopiatu',

// D
'date' => 'Data',
'dernier_ajout' => 'Azken eranskinak',
'dernieres_breves' => 'Azken laburrak',
'derniers_articles' => 'Azken artikuluak',
'derniers_commentaires' => 'Azken oharrak',
'derniers_messages_forum' => 'Berri-taldeetan argitaratu azken berriak',
'documents_interdits_forum' => 'Dokumentuak debekatuak dira berri-taldeetan',

// E
'edition_mode_texte' => 'Honen edizioa testu formatuan',
'en_reponse' => 'Erantzunez',
'en_resume' => 'Laburbilduz',
'envoyer_message' => 'Mezua bidali',
'espace_prive' => 'Leku pribatua',

// F
'formats_acceptes' => 'Onartutako berri-taldeak : @formats@.',
'forum' => 'Berri-taldea',

// H
'hierarchie_site' => 'Gunearen hierarkia',

// J
'jours' => 'Egun',

// L
'lien_connecter' => 'Konektatu',

// M
'meme_auteur' => 'Egile berak',
'meme_rubrique' => 'Gai bera',
'memes_auteurs' => 'Egile berak',
'message' => 'Mezua',
'messages_forum' => 'Berri-taldeetako mezuak',
'messages_recents' => 'Berri-taldeetako azken mezuak',
'mots_clefs' => 'Gako-hitz',
'mots_clefs_meme_groupe' => 'Talde bereko hitz-gakoak',

// N
'navigation' => 'Arakatu',
'nom' => 'Izena',
'nouveautes' => 'Azken berriak',
'nouveautes_web' => 'Web-ek azken berriak',
'nouveaux_articles' => 'Artikulu berriak',
'nouvelles_breves' => 'Azken laburrak',

// P
'page_precedente' => 'Aurreko orrialdea',
'page_suivante' => 'Hurrengo orrialdea',
'par_auteur' => 'Egilea',
'participer_site' => 'Gunekogora-beheretan parte har dezakezu eta zure artikuluak proposatu izena emanez. Segidan, e-posta batez bidez, gunearen eremu pribatuan sartzeko zure atzipen-kodeak ukanen dituzu.',
'plan_site' => 'Gunearen mapa',
'popularite' => 'Arrakasta',
'poster_message' => 'Mezua postatu',
'proposer_site' => 'Eremu honetan gehitzeko gunea proposa dezakezu:',

// R
'repondre_article' => 'Artikuluari erantzun',
'repondre_breve' => 'Laburrari erantzun',
'repondre_message' => 'Mezuari erantzun',
'resultats_recherche' => 'Bilaketaren emaitzak',
'retour_debut_forums' => 'Berri-taldeen hasierara',
'rubrique' => 'Eremua',
'rubriques' => 'Eremuak',

// S
'signatures_petition' => 'Sinadurak',
'site_realise_avec_spip' => 'SPIPekin eraiki gunea',
'sites_web' => 'Webguneak',
'sous_rubriques' => 'Azpi-eremuak',
'spam' => 'Spam',
'suite' => 'Segida',
'sur_web' => 'Web-ean',
'syndiquer_rubrique' => 'Eremu hau sindikatu',
'syndiquer_site' => 'Gune guzia sindikatu',

// T
'texte_lettre_information' => 'Hona gunearen informazio gutuna',
'texte_lettre_information_2' => 'Gutunak ondoko egunetik argitaratu artikuluak eta laburrak biltzen ditu',

// V
'ver_imprimer' => 'Inprimatzeko bertsioa',
'voir_en_ligne' => 'Linean ikusi',
'voir_squelette' => 'Orri hunen eskeletoa ikusi'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Ataria',
'article' => 'Article', # NEW
'articles' => 'Artikuluak',
'articles_auteur' => 'Egile honen artikuluak',
'articles_populaires' => 'artikulu arrakastatsuenak',
'articles_rubrique' => 'Eremu honetako artikuluak',
'aucun_article' => 'Ez dago artikulurik helbide honetan',
'aucun_auteur' => 'Ez dago egilerik helbide honetan',
'aucun_site' => 'ez dago gunerik helbide honetan',
'aucune_breve' => 'Ez dago laburrik helbide honetan',
'aucune_rubrique' => 'Ez dago gairik helbide honetan',
'auteur' => 'Auteur', # NEW
'autres' => 'Beste',
'autres_breves' => 'beste laburrak',
'autres_groupes_mots_clefs' => 'Beste gako-hitz multzoak',
'autres_sites' => 'Beste guneak',

// B
'bonjour' => 'Agur',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Laburrak',

// C
'commenter_site' => 'Guneari buruz iruzkina egin',
'copie_document_impossible' => 'Dokumentua ezin da kopiatu',

// D
'date' => 'Data',
'dernier_ajout' => 'Azken eranskinak',
'dernieres_breves' => 'Azken laburrak',
'derniers_articles' => 'Azken artikuluak',
'derniers_commentaires' => 'Azken oharrak',
'derniers_messages_forum' => 'Berri-taldeetan argitaratu azken berriak',
'documents_interdits_forum' => 'Dokumentuak debekatuak dira berri-taldeetan',

// E
'edition_mode_texte' => 'Honen edizioa testu formatuan',
'en_reponse' => 'Erantzunez',
'en_resume' => 'Laburbilduz',
'envoyer_message' => 'Mezua bidali',
'espace_prive' => 'Leku pribatua',

// F
'formats_acceptes' => 'Onartutako berri-taldeak : @formats@.',
'forum' => 'Berri-taldea',

// H
'hierarchie_site' => 'Gunearen hierarkia',

// J
'jours' => 'Egun',

// L
'lien_connecter' => 'Konektatu',

// M
'meme_auteur' => 'Egile berak',
'meme_rubrique' => 'Gai bera',
'memes_auteurs' => 'Egile berak',
'message' => 'Mezua',
'messages_forum' => 'Berri-taldeetako mezuak',
'messages_recents' => 'Berri-taldeetako azken mezuak',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Gako-hitz',
'mots_clefs_meme_groupe' => 'Talde bereko hitz-gakoak',

// N
'navigation' => 'Arakatu',
'nom' => 'Izena',
'nouveautes' => 'Azken berriak',
'nouveautes_web' => 'Web-ek azken berriak',
'nouveaux_articles' => 'Artikulu berriak',
'nouvelles_breves' => 'Azken laburrak',

// P
'page_precedente' => 'Aurreko orrialdea',
'page_suivante' => 'Hurrengo orrialdea',
'par_auteur' => 'Egilea',
'participer_site' => 'Gunekogora-beheretan parte har dezakezu eta zure artikuluak proposatu izena emanez. Segidan, e-posta batez bidez, gunearen eremu pribatuan sartzeko zure atzipen-kodeak ukanen dituzu.',
'plan_site' => 'Gunearen mapa',
'popularite' => 'Arrakasta',
'poster_message' => 'Mezua postatu',
'proposer_site' => 'Eremu honetan gehitzeko gunea proposa dezakezu:',

// R
'repondre_article' => 'Artikuluari erantzun',
'repondre_breve' => 'Laburrari erantzun',
'repondre_message' => 'Mezuari erantzun',
'resultats_recherche' => 'Bilaketaren emaitzak',
'retour_debut_forums' => 'Berri-taldeen hasierara',
'rubrique' => 'Eremua',
'rubriques' => 'Eremuak',

// S
'signatures_petition' => 'Sinadurak',
'site_realise_avec_spip' => 'SPIPekin eraiki gunea',
'sites_web' => 'Webguneak',
'sous_rubriques' => 'Azpi-eremuak',
'spam' => 'Spam',
'suite' => 'Segida',
'sur_web' => 'Web-ean',
'syndiquer_rubrique' => 'Eremu hau sindikatu',
'syndiquer_site' => 'Gune guzia sindikatu',

// T
'texte_lettre_information' => 'Hona gunearen informazio gutuna',
'texte_lettre_information_2' => 'Gutunak ondoko egunetik argitaratu artikuluak eta laburrak biltzen ditu',

// V
'ver_imprimer' => 'Inprimatzeko bertsioa',
'voir_en_ligne' => 'Linean ikusi',
'voir_squelette' => 'Orri hunen eskeletoa ikusi'
);

?>
